==> haskell-microlens-ghc-0.4.8.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-ghc
version: 0.4.8.0
id: microlens-ghc-0.4.8.0-GRbHpdx0jQM6CR6rmnZB7F
key: microlens-ghc-0.4.8.0-GRbHpdx0jQM6CR6rmnZB7F
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).
    .
    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
indefinite: False
exposed-modules:
    Lens.Micro.GHC Lens.Micro.GHC.Internal
abi: 9191afdda7efdadffe2883ef1e17c364
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/microlens-ghc-0.4.8.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/microlens-ghc-0.4.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/microlens-ghc-0.4.8.0
hs-libraries: HSmicrolens-ghc-0.4.8.0-GRbHpdx0jQM6CR6rmnZB7F
depends:
    array-0.5.2.0 base-4.10.0.0 bytestring-0.10.8.2 containers-0.5.10.2
    microlens-0.4.8.1-HUhGDwljLwYJLac51xSk3I transformers-0.5.2.0
abi-depends: array-0.5.2.0=5abf025fb7bf60079ec1f42bab285152
             base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             microlens-0.4.8.1-HUhGDwljLwYJLac51xSk3I=67b3a88d8320ac1eb1fa05f75e3434a2
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
haddock-interfaces: /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock
haddock-html: /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-ghc-0.4.8.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-ghc
version: 0.4.8.0
id: microlens-ghc-0.4.8.0-HkyUtqWBKMpJSdUj08iMnR
key: microlens-ghc-0.4.8.0-HkyUtqWBKMpJSdUj08iMnR
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).
    .
    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
indefinite: False
exposed-modules:
    Lens.Micro.GHC Lens.Micro.GHC.Internal
abi: a353aebba1dc4e0a2e5c22e24d21b168
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-ghc-0.4.8.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-ghc-0.4.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/microlens-ghc-0.4.8.0
hs-libraries: HSmicrolens-ghc-0.4.8.0-HkyUtqWBKMpJSdUj08iMnR
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    microlens-0.4.8.1-7SYUbX7BsEv8bVxypsAUmf transformers-0.5.2.0
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             microlens-0.4.8.1-7SYUbX7BsEv8bVxypsAUmf=4a2398c3f847dcb0d93febf5e9ae665a
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock
haddock-html: /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
